@@ -1,23 +1,20 @@
-# -*- coding: utf-8 -*-
 """Gaussian input plugin."""
-from __future__ import absolute_import
 
-from aiida.orm import Dict, RemoteData, Float
+import pymatgen.io.gaussian as mgaus
 from aiida.common import CalcInfo, CodeInfo
 
 # from aiida.cmdline.utils import echo
 from aiida.engine import CalcJob
+from aiida.orm import Dict, Float, RemoteData
 from aiida.plugins import DataFactory
 
-import pymatgen.io.gaussian as mgaus
-
-StructureData = DataFactory("structure")
+StructureData = DataFactory("core.structure")
 
 
 class GaussianCalculation(CalcJob):
     """
     AiiDA calculation plugin wrapping Gaussian
-    
+
     Template:
 
     parameters = Dict(dict={
@@ -47,7 +44,7 @@ class GaussianCalculation(CalcJob):
 
     @classmethod
     def define(cls, spec):
-        super(GaussianCalculation, cls).define(spec)
+        super().define(spec)
 
         # Input parameters
         spec.input(
@@ -57,7 +54,9 @@ class GaussianCalculation(CalcJob):
             help="Input structure; will be converted to pymatgen object",
         )
 
-        spec.input("parameters", valid_type=Dict, required=True, help="Input parameters")
+        spec.input(
+            "parameters", valid_type=Dict, required=True, help="Input parameters"
+        )
         spec.input(
             "settings",
             valid_type=Dict,
@@ -162,7 +161,7 @@ class GaussianCalculation(CalcJob):
                            the plugin should put all its files.
         """
 
-        if 'structure' in self.inputs:
+        if "structure" in self.inputs:
             pmg_structure = self.inputs.structure.get_pymatgen_molecule()
         else:
             # If structure is not specified, it is read from the chk file
@@ -204,7 +203,7 @@ class GaussianCalculation(CalcJob):
             comp_uuid = self.inputs.parent_calc_folder.computer.uuid
             remote_path = self.inputs.parent_calc_folder.get_remote_path()
             copy_info = (comp_uuid, remote_path, self.PARENT_FOLDER_NAME)
-            if (self.inputs.code.computer.uuid == comp_uuid):
+            if self.inputs.code.computer.uuid == comp_uuid:
                 # if running on the same computer - make a symlink
                 # if not - copy the folder
                 calcinfo.remote_symlink_list.append(copy_info)
@@ -229,13 +228,17 @@ class GaussianCalculation(CalcJob):
             pmg_structure,
             title="input generated by the aiida-gaussian plugin",
             charge=param_dict.get("charge"),
-            spin_multiplicity=param_dict.get("multiplicity", param_dict.get("spin_multiplicity")),
+            spin_multiplicity=param_dict.get(
+                "multiplicity", param_dict.get("spin_multiplicity")
+            ),
             functional=param_dict.get("functional"),
             basis_set=param_dict.get("basis_set"),
             route_parameters=param_dict.get("route_parameters"),
             input_parameters=param_dict.get("input_parameters"),
             link0_parameters=param_dict.get("link0_parameters"),
-            dieze_tag=param_dict.get("dieze_tag", "#N"),  # normal print level by default
+            dieze_tag=param_dict.get(
+                "dieze_tag", "#N"
+            ),  # normal print level by default
         )
 
         return inp.to_string(cart_coords=True)
