@@ -1,5 +1,6 @@
-# -*- coding: utf-8 -*-
 """AiiDA-Gaussian workchains"""
 
 from .base import GaussianBaseWorkChain
-from .cubes import GaussianCubesWorkChain
\ No newline at end of file
+from .cubes import GaussianCubesWorkChain
+
+__all__ = ["GaussianBaseWorkChain", "GaussianCubesWorkChain"]
